@@ -17,8 +17,11 @@ from cryspy_editor.widgets.w_loop_constr import w_for_loop_constr
 from cryspy_editor.widgets.w_meas_inelasticl import w_for_meas_inelasticl
 from cryspy_editor.widgets.w_pd2d_meas import w_for_pd2d_meas
 from cryspy_editor.widgets.w_pd2d_proc import w_for_pd2d_proc
+from cryspy_editor.widgets.w_pd_peak import w_for_pd_peak
 from cryspy_editor.widgets.w_pd_meas import w_for_pd_meas
 from cryspy_editor.widgets.w_pd_proc import w_for_pd_proc
+from cryspy_editor.widgets.w_pd import w_for_pd
+from cryspy_editor.widgets.w_diffrn_refln import w_for_diffrn_refln
 from pycifstar import Data, Global, Item, Items, Loop, to_global
 
 from cryspy_editor.widgets.w_item import w_for_item
@@ -36,7 +39,9 @@ try:
     from cryspy.cif_like.cl_pd import Pd
     from cryspy.cif_like.cl_pd2d import Pd2d
     from cryspy.cif_like.cl_diffrn import Diffrn
+    from cryspy.cif_like.cl_diffrn_refln import DiffrnReflnL 
 
+    from cryspy.pd1dcif_like.cl_pd_peak import PdPeakL
     from cryspy.pd1dcif_like.cl_pd_meas import PdMeasL
     from cryspy.pd1dcif_like.cl_pd_proc import PdProcL
     from cryspy.pd2dcif_like.cl_pd2d_meas import Pd2dMeas
@@ -650,7 +655,11 @@ class cwidget(QtWidgets.QSplitter):
             pass
 
         if (FLAG_CRYSPY & (not(flag_done))):
-            if isinstance(obj, PdMeasL):
+            if isinstance(obj, PdPeakL):
+                w_for_pd_peak(obj, layout_11, layout_12, layout_13,
+                              layout_2, layout_3, w_output, thread)
+                flag_done = True
+            elif isinstance(obj, PdMeasL):
                 w_for_pd_meas(obj, layout_11, layout_12, layout_13,
                               layout_2, layout_3, w_output, thread)
                 flag_done = True
@@ -658,6 +667,10 @@ class cwidget(QtWidgets.QSplitter):
                 w_for_pd_proc(obj, layout_11, layout_12, layout_13,
                               layout_2, layout_3, w_output, thread)
                 flag_done = True
+            elif isinstance(obj, DiffrnReflnL):
+                w_for_diffrn_refln(obj, layout_11, layout_12, layout_13,
+                                   layout_2, layout_3, w_output, thread)
+                flag_done = True
             elif isinstance(obj, Pd2dMeas):
                 w_for_pd2d_meas(obj, layout_11, layout_12, layout_13,
                                 layout_2, layout_3, w_output, thread)
@@ -666,6 +679,10 @@ class cwidget(QtWidgets.QSplitter):
                 w_for_pd2d_proc(obj, layout_11, layout_12, layout_13,
                                 layout_2, layout_3, w_output, thread)
                 flag_done = True
+            elif isinstance(obj, Pd):
+                w_for_pd(obj, layout_11, layout_12, layout_13,
+                         layout_2, layout_3, w_output, thread)
+                flag_done = True
 
         if not(flag_done):
             if isinstance(obj, GlobalConstr):
