@@ -4,6 +4,7 @@ from types import FunctionType
 from cryspy import Fitable
 from cryspy import GlobalConstr
 from cryspy import DataConstr, LoopConstr, ItemConstr
+from pycifstar import Global, Data, Loop, Item
 
 
 from cryspy_editor.b_rcif_to_cryspy import L_ITEM_CLASS, L_LOOP_CLASS, L_DATA_CLASS
@@ -23,7 +24,7 @@ def temp_func_loop_help(qt_table, i_row, i_col, obj, l_ii, label):
         label.setText(get_help_for_attribute(obj.item[i_row], l_attr[l_ii[i_col]]))
     return
 
-def temp_func_item(qt_table, i_row, i_col, obj, l_ii):
+def temp_func_item_constr(qt_table, i_row, i_col, obj, l_ii):
     table_item = qt_table.item(i_row, i_col)
     val = str(table_item.text())
     l_attr = obj.MANDATORY_ATTRIBUTE + obj.OPTIONAL_ATTRIBUTE
@@ -31,6 +32,13 @@ def temp_func_item(qt_table, i_row, i_col, obj, l_ii):
         setattr(obj, l_attr[l_ii[i_row]], val)
     return
 
+def temp_func_item(qt_table, i_row, i_col, obj, l_ii):
+    table_item = qt_table.item(i_row, i_col)
+    val = str(table_item.text())
+    if i_col == 1:
+        setattr(obj, "value", val)
+    return
+
 def temp_func_item_help(qt_table, i_row, i_col, obj, l_ii, label):
     table_item = qt_table.item(i_row, i_col)
     val = str(table_item.text())
@@ -102,6 +110,36 @@ def make_qtablewidget_for_loop_constr(obj, label=None):
     w_t.cellChanged.connect(lambda _1, _2: temp_func_loop(w_t, _1, _2, obj, l_ii))
     return w_t
 
+def make_qtablewidget_for_item(obj, label=None):
+    l_attr_sh = [obj.name]
+    l_flag_m_sh = [True]
+    n_row, n_col = len(l_attr_sh), 2
+    w_t = QtWidgets.QTableWidget(n_row, n_col)
+
+    l_ii = [0]
+    l_name = l_attr_sh
+    w_t.setHorizontalHeaderLabels(["name", "value"])
+    w_t.horizontalHeader().setSectionResizeMode(QtWidgets.QHeaderView.Stretch)
+    _i_row = 0
+    for _i_row, _attr in enumerate(l_attr_sh):
+        _w_ti_0 = QtWidgets.QTableWidgetItem()
+        _w_ti_0.setText(str(_attr))
+        w_t.setItem(_i_row, 0, _w_ti_0)
+        _1 = obj.value
+        _w_ti_1 = QtWidgets.QTableWidgetItem()
+        _w_ti_1.setText(str(_1))
+        if l_flag_m_sh[_i_row]:
+            _w_ti_0.setBackground(QtGui.QColor(255, 255, 240))#Ivory
+            _w_ti_1.setBackground(QtGui.QColor(255, 255, 240))
+        else:
+            _w_ti_0.setBackground(QtGui.QColor(255, 255, 255))#White
+            _w_ti_1.setBackground(QtGui.QColor(255, 255, 255))
+
+        w_t.setItem(_i_row, 1, _w_ti_1)
+    w_t.cellChanged.connect(lambda _1, _2: temp_func_item(w_t, _1, _2, obj, l_ii))
+    w_t.setVerticalHeaderLabels(n_row*[""])
+    return w_t
+
 
 def make_qtablewidget_for_item_constr(obj, label=None):
     l_attr = obj.MANDATORY_ATTRIBUTE + obj.OPTIONAL_ATTRIBUTE
@@ -148,12 +186,12 @@ def make_qtablewidget_for_item_constr(obj, label=None):
             _w_ti_1.setBackground(QtGui.QColor(255, 255, 255))
 
         w_t.setItem(_i_row, 1, _w_ti_1)
-    w_t.cellChanged.connect(lambda _1, _2: temp_func_item(w_t, _1, _2, obj, l_ii))
+    w_t.cellChanged.connect(lambda _1, _2: temp_func_item_constr(w_t, _1, _2, obj, l_ii))
     w_t.setVerticalHeaderLabels(n_row*[""])
     return w_t
 
 
-def make_qtablewidget_for_data_constr(obj, label=None):
+def make_qtablewidget_for_data_constr(obj, label, thread):
     l_data_obj = obj.mandatory_objs + obj.optional_objs
     l_ii, l_obj_sh = [], []
 
@@ -182,10 +220,10 @@ def make_qtablewidget_for_data_constr(obj, label=None):
     w_t.setCellWidget(n_row-1, 0, pb_del)
     
     w_t.setVerticalHeaderLabels(n_row*[""])
-    pb_del.clicked.connect(lambda : del_obj_by_table(w_t, obj))
+    pb_del.clicked.connect(lambda : del_obj_by_table(w_t, obj, thread))
     return w_t
 
-def del_obj_by_table(table_widget, obj):
+def del_obj_by_table(table_widget, obj, thread):
     n_mandatory = len(obj.mandatory_objs)
     n_optional = len(obj.optional_objs)
     n_row = table_widget.rowCount()
@@ -210,7 +248,7 @@ def del_obj_by_table(table_widget, obj):
             else:
                 n_optional -= 1
                 obj.optional_objs.pop(_ind-n_mandatory)
-    
+    thread.signal_refresh.emit()   
 
 def show_info(obj, label):
     if obj.is_defined:
@@ -446,7 +484,7 @@ def show_widget(widget, state):
         widget.show()
 
 
-def add_mandatory_optional_obj(obj, label):
+def add_mandatory_optional_obj(obj, label, thread):
     """
 layout to add new attributes for DataConstr or GlobalConstr
     """
@@ -521,14 +559,14 @@ layout to add new attributes for DataConstr or GlobalConstr
     pb_add = QtWidgets.QPushButton("Add objects")
     table_widget_1.setCellWidget(n_row-1, 0, pb_add)
     table_widget_1.setVerticalHeaderLabels(n_row*[""])
-    pb_add.clicked.connect(lambda : add_obj_by_table(table_widget_1, l_cls, obj))
+    pb_add.clicked.connect(lambda : add_obj_by_table(table_widget_1, l_cls, obj, thread))
 
     layout.addWidget(table_widget_1)
 
     return layout
 
 
-def add_obj_by_table(table_widget, l_cls, obj):
+def add_obj_by_table(table_widget, l_cls, obj, thread):
     if type(obj) == GlobalConstr:
         flag_constrained = True
     elif type(obj) == DataConstr:
@@ -609,12 +647,16 @@ def add_obj_by_table(table_widget, l_cls, obj):
                     for _obj in l_add_optional_obj:
                         if not(isinstance(_obj, tuple(obj.optional_classes))):
                             obj.optional_classes.append(type(_obj))
+    thread.signal_refresh.emit()
 
-def get_layout_rciftab_obj(obj):
+def get_layout_rciftab_obj(obj, thread):
     layout = QtWidgets.QVBoxLayout()
 
     _text_edit = QtWidgets.QTextEdit()
-    _text_edit.setText(obj.to_cif(flag=True))
+    if (isinstance(obj, Global) | isinstance(obj, Data) | isinstance(obj, Loop) | isinstance(obj, Item)):
+        _text_edit.setText(str(obj))
+    else:
+        _text_edit.setText(obj.to_cif(flag=True))
     layout.addWidget(_text_edit)
 
     lay_button = QtWidgets.QHBoxLayout()
@@ -622,13 +664,17 @@ def get_layout_rciftab_obj(obj):
     button_to_obj = QtWidgets.QPushButton("add to object")
     lay_button.addWidget(button_to_obj)
     layout.addLayout(lay_button)
-    button_to_obj.clicked.connect(lambda : add_rcif_to_obj(obj, _text_edit.toPlainText()))
+    button_to_obj.clicked.connect(lambda : add_rcif_to_obj(obj, _text_edit.toPlainText(), thread))
     return layout
 
-def add_rcif_to_obj(obj, text):
+def add_rcif_to_obj(obj, text, thread):
     obj_cls = type(obj)
     obj_new = None
-    l_obj_new = obj_cls.from_cif(text)
+    if (isinstance(obj, Global) | isinstance(obj, Data) | isinstance(obj, Loop) | isinstance(obj, Item)):
+        l_obj_new = obj_cls() 
+        l_obj_new.take_from_string(text)
+    else:
+        l_obj_new = obj_cls.from_cif(text)
     if l_obj_new is not None:
         if isinstance(l_obj_new, list):
             if len(l_obj_new) != 0:
@@ -653,4 +699,14 @@ def add_rcif_to_obj(obj, text):
                 setattr(obj, f"__{_attr:}", getattr(obj_new, f"__{_attr:}"))
         if obj.is_defined:
             obj.form_object
+    elif isinstance(obj, Item):
+        obj.name = obj_new.name
+        obj.value = obj_new.value
+    elif isinstance(obj, Loop):
+        pass
+    elif isinstance(obj, Data):
+        pass
+    elif isinstance(obj, Global):
+        pass
+    thread.signal_refresh.emit()
     return
\ No newline at end of file
